@@ -12,12 +12,12 @@ sub diff {
 
     my $diff = SQL::Translator::Diff->new({
         output_db => $config->rdbms,
-        source_schema => $source,
-        target_schema => $target,
+        source_schema => $source->schema,
+        target_schema => $target->schema,
     })->compute_differences->produce_diff_sql;
 
-    # ignore first line
-    $diff =~ s/.*?\n//;
+    # ignore initial comments.
+    1 while $diff =~ s/\A--.*?\r?\n//ms;
 
     return $diff =~ /\A\s*-- No differences found;\s*\z/ms ? undef : $diff;
 }
